@@ -485,10 +485,14 @@ def _get_current_aws_profile() -> str:
         cmd = [aws_path, "configure", "list", "--no-cli-pager"]
         _, stdout, _ = _run_command(cmd, capture=True, check=False)
 
-        # Extract profile from output
-        profile_match = re.search(r"profile\s+(\S+)", stdout)
-        if profile_match and profile_match.group(1) not in ("<not", "not"):
-            return profile_match.group(1)
+        # Extract profile from output (format: "profile    : <value>    : <type>    : <location>")
+        # Match the line starting with "profile" and capture the value after the first colon
+        profile_match = re.search(r"^profile\s+:\s+(\S+)", stdout, re.MULTILINE)
+        if profile_match:
+            profile_value = profile_match.group(1)
+            # Check if the profile is actually set (not "<not" or "not")
+            if profile_value not in ("<not", "not"):
+                return profile_value
     except:
         pass
 
