@@ -3,6 +3,4 @@
 from .engine_commands import engine_cli
 from .studio_commands import studio_cli
 
-__all__ = ['engine_cli', 'studio_cli']
-
-
+__all__ = ["engine_cli", "studio_cli"]
