@@ -112,12 +112,18 @@ def engine_cli():
     ),
 )
 @click.option("--size", "boot_disk_size", type=int, help="Boot disk size in GB")
+@click.option(
+    "--user",
+    default=None,
+    help="User to launch engine for (defaults to current user, use for testing/admin)",
+)
 @click.option(
     "--no-wait", is_flag=True, help="Return immediately without waiting for readiness"
 )
 @click.option(
     "--skip-ssh-config", is_flag=True, help="Don't automatically update SSH config"
 )
+@click.option("--yes", "-y", is_flag=True, help="Skip confirmation for non-dev environments")
 @click.option(
     "--env",
     default=None,
@@ -127,11 +133,13 @@ def launch_engine(
     name: str,
     engine_type: str,
     boot_disk_size: Optional[int],
+    yes: bool,
+    user: Optional[str],
     no_wait: bool,
     skip_ssh_config: bool,
     env: Optional[str],
 ):
-    """Launch a new engine and wait for it to be ready."""
+    """Launch a new engine for the current user (or specified user with --user flag)."""
 
     # Check AWS auth first to provide clear error messages
     check_aws_auth()
@@ -142,7 +150,7 @@ def launch_engine(
         click.echo(f"🔍 Detected environment: {env}")
 
         # Require confirmation for non-dev environments
-        if env != "dev":
+        if env != "dev" and not yes:
             if not click.confirm(
                 f"⚠️  You are about to launch in {env.upper()}. Continue?"
             ):
@@ -151,13 +159,15 @@ def launch_engine(
 
     client = StudioManagerClient(environment=env)
 
-    try:
-        user = get_aws_username()
-    except RuntimeError as e:
-        click.echo(f"✗ {e}", err=True)
-        raise click.Abort()
+    # Get user (from flag or current AWS user)
+    if user is None:
+        try:
+            user = get_aws_username()
+        except RuntimeError as e:
+            click.echo(f"✗ {e}", err=True)
+            raise click.Abort()
 
-    click.echo(f"🚀 Launching {engine_type} engine '{name}'...")
+    click.echo(f"🚀 Launching {engine_type} engine '{name}' for {user}...")
 
     try:
         # Launch the engine
@@ -193,7 +203,7 @@ def launch_engine(
 
             click.echo(f"\nConnect with:")
             click.echo(f"  dh studio attach {name}")
-            click.echo(f"  dh engine ssh {name}")
+            click.echo(f"  ssh {name}")
 
         except TimeoutError:
             click.echo(f"\n⚠ Engine is still initializing. Check status with:")
@@ -212,13 +222,14 @@ def launch_engine(
 @click.option(
     "--skip-ssh-config", is_flag=True, help="Don't automatically update SSH config"
 )
+@click.option("--yes", "-y", is_flag=True, help="Skip confirmation for non-dev environments")
 @click.option(
     "--env",
     default=None,
     help="Environment (dev, sand, prod) - auto-detected if not specified",
 )
 def start_engine(
-    name_or_id: str, no_wait: bool, skip_ssh_config: bool, env: Optional[str]
+    name_or_id: str, no_wait: bool, skip_ssh_config: bool, yes: bool, env: Optional[str]
 ):
     """Start a stopped engine."""
 
@@ -231,7 +242,7 @@ def start_engine(
         click.echo(f"🔍 Detected environment: {env}")
 
         # Require confirmation for non-dev environments
-        if env != "dev":
+        if env != "dev" and not yes:
             if not click.confirm(
                 f"⚠️  You are about to operate in {env.upper()}. Continue?"
             ):
@@ -321,7 +332,7 @@ def start_engine(
 
             click.echo(f"\nConnect with:")
             click.echo(f"  dh studio attach {engine_name}")
-            click.echo(f"  dh engine ssh {engine_name}")
+            click.echo(f"  ssh {engine_name}")
 
         except TimeoutError:
             click.echo(f"\n⚠ Engine is still starting. Check status with:")
@@ -334,12 +345,13 @@ def start_engine(
 
 @engine_cli.command("stop")
 @click.argument("name_or_id")
+@click.option("--yes", "-y", is_flag=True, help="Skip confirmation for non-dev environments")
 @click.option(
     "--env",
     default=None,
     help="Environment (dev, sand, prod) - auto-detected if not specified",
 )
-def stop_engine(name_or_id: str, env: Optional[str]):
+def stop_engine(name_or_id: str, yes: bool, env: Optional[str]):
     """Stop a running engine."""
 
     # Check AWS auth first to provide clear error messages
@@ -351,7 +363,7 @@ def stop_engine(name_or_id: str, env: Optional[str]):
         click.echo(f"🔍 Detected environment: {env}")
 
         # Require confirmation for non-dev environments
-        if env != "dev":
+        if env != "dev" and not yes:
             if not click.confirm(
                 f"⚠️  You are about to operate in {env.upper()}. Continue?"
             ):
@@ -404,7 +416,7 @@ def terminate_engine(name_or_id: str, yes: bool, env: Optional[str]):
         click.echo(f"🔍 Detected environment: {env}")
 
         # Require confirmation for non-dev environments
-        if env != "dev":
+        if env != "dev" and not yes:
             if not click.confirm(
                 f"⚠️  You are about to operate in {env.upper()}. Continue?"
             ):
@@ -577,13 +589,13 @@ def list_engines(env: Optional[str]):
 
         # Table header - reordered per user request: Name, State, User, Type, Instance ID
         click.echo(
-            f"{'Name':<12} {'State':<12} {'User':<12} {'Type':<12} {'Instance ID':<20}"
+            f"{'Name':<30} {'State':<12} {'User':<12} {'Type':<12} {'Instance ID':<20}"
         )
-        click.echo("-" * 72)
+        click.echo("-" * 90)
 
         # Table rows
         for engine in engines:
-            name = engine.get("name", "unknown")[:11]
+            name = engine.get("name", "unknown")[:29]
             state = engine.get("state", "unknown")[:11]
             user = engine.get("user", "unknown")[:11]
             engine_type = engine.get("engine_type", "unknown")[:11]
@@ -591,12 +603,16 @@ def list_engines(env: Optional[str]):
 
             # Color the state in the list view
             if state == "running":
-                state_display = f"\033[32m{state:<12}\033[0m"
+                state_display = f"\033[32m{state:<12}\033[0m"  # Green
+            elif state in ["starting", "stopping", "pending"]:
+                state_display = f"\033[33m{state:<12}\033[0m"  # Yellow
+            elif state == "stopped":
+                state_display = f"\033[37m{state:<12}\033[0m"  # White
             else:
-                state_display = f"{state:<12}"
+                state_display = f"{state:<12}"  # No color for other states
 
             click.echo(
-                f"{name:<12} {state_display} {user:<12} {engine_type:<12} {instance_id:<20}"
+                f"{name:<30} {state_display} {user:<12} {engine_type:<12} {instance_id:<20}"
             )
 
         click.echo(f"\nTotal: {len(engines)} engine(s)")
@@ -919,50 +935,6 @@ def resize_engine(
         raise click.Abort()
 
 
-@engine_cli.command("gami")
-@click.argument("name_or_id")
-@click.option(
-    "--env",
-    default=None,
-    help="Environment (dev, sand, prod) - auto-detected if not specified",
-)
-def create_ami(name_or_id: str, env: Optional[str]):
-    """Create a Golden AMI from an engine."""
-
-    # Check AWS auth and auto-detect environment if not specified
-    check_aws_auth()
-
-    if env is None:
-        env = detect_aws_environment()
-
-    client = StudioManagerClient(environment=env)
-
-    try:
-        # Find engine
-        engine = client.get_engine_by_name(name_or_id)
-        if not engine:
-            engine = {"instance_id": name_or_id, "name": name_or_id}
-
-        engine_id = engine["instance_id"]
-        engine_name = engine.get("name", engine_id)
-
-        click.echo(f"Creating Golden AMI from '{engine_name}'...")
-
-        result = client.create_ami(engine_id)
-
-        if "error" in result:
-            click.echo(f"✗ Error: {result['error']}", err=True)
-            raise click.Abort()
-
-        ami_id = result.get("ami_id")
-        click.echo(f"✓ AMI creation started: {ami_id}")
-        click.echo(f"  This will take several minutes")
-
-    except Exception as e:
-        click.echo(f"✗ Error: {e}", err=True)
-        raise click.Abort()
-
-
 @engine_cli.command("debug")
 @click.argument("name_or_id")
 @click.option(
