@@ -161,7 +161,7 @@ def format_idle_state(
         for sensor_name, sensor_data in idle_state["sensors"].items():
             emoji = sensor_emojis.get(sensor_name.lower(), "📊")
             active = sensor_data.get("active", False)
-            
+
             # Special formatting for coffee sensor
             if sensor_name.lower() == "coffee" and active:
                 # Extract minutes from details for cleaner display
@@ -178,7 +178,9 @@ def format_idle_state(
                         f"\n{emoji} {sensor_name.upper()} {status_icon.split(chr(10))[0]}"
                     )
                     # Add reason on next line
-                    reason_line = status_icon.split("\n")[1] if "\n" in status_icon else ""
+                    reason_line = (
+                        status_icon.split("\n")[1] if "\n" in status_icon else ""
+                    )
                     if reason_line:
                         lines.append(reason_line)
                 else:
@@ -187,7 +189,7 @@ def format_idle_state(
             # Show details if available (skip for active coffee sensor with special formatting)
             if sensor_name.lower() == "coffee" and active:
                 continue  # Already showed coffee details in special format above
-            
+
             details = sensor_data.get("details", {})
             if details:
                 for key, value in details.items():
