@@ -6,7 +6,7 @@ from typing import Optional
 import click
 
 from .api_client import StudioManagerClient
-from .auth import check_aws_auth, get_aws_username, detect_aws_environment
+from .auth import check_aws_auth, detect_aws_environment, get_aws_username
 from .progress import format_time_ago, wait_with_progress
 
 
@@ -23,41 +23,64 @@ def studio_cli():
 
 @studio_cli.command("create")
 @click.option("--size", "size_gb", type=int, default=100, help="Studio size in GB")
-@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
-def create_studio(size_gb: int, env: Optional[str]):
-    """Create a new studio for the current user."""
+@click.option(
+    "--user",
+    default=None,
+    help="User to create studio for (defaults to current user, use for testing/admin)",
+)
+@click.option(
+    "--env",
+    default=None,
+    help="Environment (dev, sand, prod) - auto-detected if not specified",
+)
+def create_studio(size_gb: int, user: Optional[str], env: Optional[str]):
+    """Create a new studio for the current user (or specified user with --user flag)."""
 
     # Check AWS auth first to provide clear error messages
     check_aws_auth()
-    
+
     # Auto-detect environment if not specified
     if env is None:
         env = detect_aws_environment()
         click.echo(f"🔍 Detected environment: {env}")
-        
+
         # Require confirmation for non-dev environments
         if env != "dev":
-            if not click.confirm(f"⚠️  You are about to create in {env.upper()}. Continue?"):
+            if not click.confirm(
+                f"⚠️  You are about to create in {env.upper()}. Continue?"
+            ):
                 click.echo("Cancelled")
                 raise click.Abort()
 
     client = StudioManagerClient(environment=env)
 
-    try:
-        user = get_aws_username()
-    except RuntimeError as e:
-        click.echo(f"✗ {e}", err=True)
-        raise click.Abort()
+    # Get user (from flag or current AWS user)
+    if user is None:
+        try:
+            user = get_aws_username()
+        except RuntimeError as e:
+            click.echo(f"✗ {e}", err=True)
+            raise click.Abort()
 
     try:
-        # Check if user already has a studio
-        existing = client.get_my_studio()
-        if existing:
-            click.echo(
-                f"✗ You already have a studio: {existing['studio_id']}", err=True
-            )
-            click.echo(f"   Use 'dh studio delete' to remove it first")
-            raise click.Abort()
+        # Check if user already has a studio (only for current user)
+        try:
+            current_aws_user = get_aws_username()
+            if user == current_aws_user:
+                existing = client.get_my_studio()
+                if existing:
+                    click.echo(
+                        f"✗ You already have a studio: {existing['studio_id']}",
+                        err=True,
+                    )
+                    click.echo(f"   Use 'dh studio delete' to remove it first")
+                    raise click.Abort()
+        except click.Abort:
+            # Re-raise Abort so it propagates correctly
+            raise
+        except Exception:
+            # If we can't get current user for other reasons, skip the check
+            pass
 
         click.echo(f"Creating {size_gb}GB studio for {user}...")
 
@@ -79,13 +102,22 @@ def create_studio(size_gb: int, env: Optional[str]):
 
 @studio_cli.command("delete")
 @click.option("--yes", "-y", is_flag=True, help="Skip confirmation")
-@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
-def delete_studio(yes: bool, env: Optional[str]):
-    """Delete your studio (WARNING: This deletes all data!)."""
+@click.option(
+    "--user",
+    default=None,
+    help="User whose studio to delete (defaults to current user, use for testing/admin)",
+)
+@click.option(
+    "--env",
+    default=None,
+    help="Environment (dev, sand, prod) - auto-detected if not specified",
+)
+def delete_studio(yes: bool, user: Optional[str], env: Optional[str]):
+    """Delete your studio (or another user's studio with --user flag)."""
 
     # Check AWS auth first to provide clear error messages
     check_aws_auth()
-    
+
     # Auto-detect environment if not specified
     if env is None:
         env = detect_aws_environment()
@@ -93,16 +125,26 @@ def delete_studio(yes: bool, env: Optional[str]):
     client = StudioManagerClient(environment=env)
 
     try:
-        # Get user's studio
-        studio = client.get_my_studio()
-        if not studio:
-            click.echo("You don't have a studio")
-            return
+        # Get studio (for current user or specified user)
+        if user is None:
+            studio = client.get_my_studio()
+            if not studio:
+                click.echo("You don't have a studio")
+                return
+        else:
+            # Get studio by user - list all and filter
+            result = client.list_studios()
+            studios = result.get("studios", [])
+            user_studios = [s for s in studios if s.get("user") == user]
+            if not user_studios:
+                click.echo(f"User '{user}' doesn't have a studio")
+                return
+            studio = user_studios[0]
 
         studio_id = studio["studio_id"]
 
         # Must be detached first
-        if studio["status"] == "in-use":
+        if studio["status"] == "attached":
             click.echo("✗ Studio must be detached before deletion", err=True)
             click.echo("  Run: dh studio detach")
             raise click.Abort()
@@ -136,13 +178,22 @@ def delete_studio(yes: bool, env: Optional[str]):
 
 
 @studio_cli.command("status")
-@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
-def studio_status(env: Optional[str]):
+@click.option(
+    "--user",
+    default=None,
+    help="User whose studio status to check (defaults to current user, use for testing/admin)",
+)
+@click.option(
+    "--env",
+    default=None,
+    help="Environment (dev, sand, prod) - auto-detected if not specified",
+)
+def studio_status(user: Optional[str], env: Optional[str]):
     """Show information about your studio."""
 
     # Check AWS auth first to provide clear error messages
     check_aws_auth()
-    
+
     # Auto-detect environment if not specified
     if env is None:
         env = detect_aws_environment()
@@ -150,37 +201,53 @@ def studio_status(env: Optional[str]):
     client = StudioManagerClient(environment=env)
 
     try:
-        studio = client.get_my_studio()
-        if not studio:
-            click.echo("You don't have a studio yet. Create one with:")
-            click.echo("  dh studio create")
-            return
+        # Get studio (for current user or specified user)
+        if user is None:
+            studio = client.get_my_studio()
+            if not studio:
+                click.echo("You don't have a studio yet. Create one with:")
+                click.echo("  dh studio create")
+                return
+        else:
+            # Get studio by user - list all and filter
+            result = client.list_studios()
+            studios = result.get("studios", [])
+            user_studios = [s for s in studios if s.get("user") == user]
+            if not user_studios:
+                click.echo(f"User '{user}' doesn't have a studio")
+                return
+            studio = user_studios[0]
 
-        # Reordered output: User, Size, Status, Account, Created, Studio ID
+        # Reordered output: User, Status, Attached to, Account, Size, Created, Studio ID
         click.echo(f"User: {studio['user']}")
-        click.echo(f"Size: {studio['size_gb']}GB")
-        click.echo(f"Status: {studio['status']}")
+        # Status in blue
+        click.echo(f"Status: \033[34m{studio['status']}\033[0m")
+        # Attached to in blue (if present)
+        if studio.get("attached_to"):
+            click.echo(f"Attached to: \033[34m{studio['attached_to']}\033[0m")
         click.echo(f"Account: {env}")
-        if studio.get('created_at'):
+        click.echo(f"Size: {studio['size_gb']}GB")
+        if studio.get("created_at"):
             click.echo(f"Created: {format_time_ago(studio['created_at'])}")
         click.echo(f"Studio ID: {studio['studio_id']}")
 
-        if studio.get("attached_to"):
-            click.echo(f"Attached to: {studio['attached_to']}")
-
     except Exception as e:
         click.echo(f"✗ Error: {e}", err=True)
         raise click.Abort()
 
 
 @studio_cli.command("list")
-@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+@click.option(
+    "--env",
+    default=None,
+    help="Environment (dev, sand, prod) - auto-detected if not specified",
+)
 def list_studios(env: Optional[str]):
     """List all studios."""
 
     # Check AWS auth first to provide clear error messages
     check_aws_auth()
-    
+
     # Auto-detect environment if not specified
     if env is None:
         env = detect_aws_environment()
@@ -222,13 +289,22 @@ def list_studios(env: Optional[str]):
 
 @studio_cli.command("attach")
 @click.argument("engine_name_or_id")
-@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
-def attach_studio(engine_name_or_id: str, env: Optional[str]):
+@click.option(
+    "--user",
+    default=None,
+    help="User whose studio to attach (defaults to current user, use for testing/admin)",
+)
+@click.option(
+    "--env",
+    default=None,
+    help="Environment (dev, sand, prod) - auto-detected if not specified",
+)
+def attach_studio(engine_name_or_id: str, user: Optional[str], env: Optional[str]):
     """Attach your studio to an engine with progress tracking."""
 
     # Check AWS auth first to provide clear error messages
     check_aws_auth()
-    
+
     # Auto-detect environment if not specified
     if env is None:
         env = detect_aws_environment()
@@ -236,12 +312,22 @@ def attach_studio(engine_name_or_id: str, env: Optional[str]):
     client = StudioManagerClient(environment=env)
 
     try:
-        # Get user's studio
-        studio = client.get_my_studio()
-        if not studio:
-            click.echo("✗ You don't have a studio yet. Create one with:", err=True)
-            click.echo("  dh studio create")
-            raise click.Abort()
+        # Get studio (for current user or specified user)
+        if user is None:
+            studio = client.get_my_studio()
+            if not studio:
+                click.echo("✗ You don't have a studio yet. Create one with:", err=True)
+                click.echo("  dh studio create")
+                raise click.Abort()
+        else:
+            # Get studio by user - list all and filter
+            result = client.list_studios()
+            studios = result.get("studios", [])
+            user_studios = [s for s in studios if s.get("user") == user]
+            if not user_studios:
+                click.echo(f"✗ User '{user}' doesn't have a studio", err=True)
+                raise click.Abort()
+            studio = user_studios[0]
 
         studio_id = studio["studio_id"]
 
@@ -287,7 +373,7 @@ def attach_studio(engine_name_or_id: str, env: Optional[str]):
             click.echo(f"\nYour files are now available at:")
             click.echo(f"  /studios/{studio['user']}/")
             click.echo(f"\nConnect with:")
-            click.echo(f"  dh engine ssh {engine_name}")
+            click.echo(f"  ssh {engine_name}")
 
         except Exception as e:
             # Get final status to show error details
@@ -324,13 +410,22 @@ def attach_studio(engine_name_or_id: str, env: Optional[str]):
 
 
 @studio_cli.command("detach")
-@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
-def detach_studio(env: Optional[str]):
+@click.option(
+    "--user",
+    default=None,
+    help="User whose studio to detach (defaults to current user, use for testing/admin)",
+)
+@click.option(
+    "--env",
+    default=None,
+    help="Environment (dev, sand, prod) - auto-detected if not specified",
+)
+def detach_studio(user: Optional[str], env: Optional[str]):
     """Detach your studio from its engine."""
 
     # Check AWS auth first to provide clear error messages
     check_aws_auth()
-    
+
     # Auto-detect environment if not specified
     if env is None:
         env = detect_aws_environment()
@@ -338,13 +433,23 @@ def detach_studio(env: Optional[str]):
     client = StudioManagerClient(environment=env)
 
     try:
-        # Get user's studio
-        studio = client.get_my_studio()
-        if not studio:
-            click.echo("✗ You don't have a studio", err=True)
-            raise click.Abort()
+        # Get studio (for current user or specified user)
+        if user is None:
+            studio = client.get_my_studio()
+            if not studio:
+                click.echo("✗ You don't have a studio", err=True)
+                raise click.Abort()
+        else:
+            # Get studio by user - list all and filter
+            result = client.list_studios()
+            studios = result.get("studios", [])
+            user_studios = [s for s in studios if s.get("user") == user]
+            if not user_studios:
+                click.echo(f"✗ User '{user}' doesn't have a studio", err=True)
+                raise click.Abort()
+            studio = user_studios[0]
 
-        if studio["status"] != "in-use":
+        if studio["status"] != "attached":
             click.echo(
                 f"✗ Studio is not attached (status: {studio['status']})", err=True
             )
@@ -374,24 +479,44 @@ def detach_studio(env: Optional[str]):
 
 @studio_cli.command("resize")
 @click.option("--size", "-s", required=True, type=int, help="New size in GB")
-@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
-def resize_studio(size: int, env: Optional[str]):
+@click.option("--yes", "-y", is_flag=True, help="Skip confirmation")
+@click.option(
+    "--user",
+    default=None,
+    help="User whose studio to resize (defaults to current user, use for testing/admin)",
+)
+@click.option(
+    "--env",
+    default=None,
+    help="Environment (dev, sand, prod) - auto-detected if not specified",
+)
+def resize_studio(size: int, yes: bool, user: Optional[str], env: Optional[str]):
     """Resize your studio volume (requires detachment)."""
-    
+
     # Check AWS auth and auto-detect environment if not specified
     check_aws_auth()
-    
+
     if env is None:
         env = detect_aws_environment()
 
     client = StudioManagerClient(environment=env)
 
     try:
-        # Get user's studio
-        studio = client.get_my_studio()
-        if not studio:
-            click.echo("✗ You don't have a studio", err=True)
-            raise click.Abort()
+        # Get studio (for current user or specified user)
+        if user is None:
+            studio = client.get_my_studio()
+            if not studio:
+                click.echo("✗ You don't have a studio", err=True)
+                raise click.Abort()
+        else:
+            # Get studio by user - list all and filter
+            result = client.list_studios()
+            studios = result.get("studios", [])
+            user_studios = [s for s in studios if s.get("user") == user]
+            if not user_studios:
+                click.echo(f"✗ User '{user}' doesn't have a studio", err=True)
+                raise click.Abort()
+            studio = user_studios[0]
 
         studio_id = studio["studio_id"]
 
@@ -412,7 +537,9 @@ def resize_studio(size: int, env: Optional[str]):
             )
             raise click.Abort()
 
-        if not click.confirm(f"Resize studio from {current_size}GB to {size}GB?"):
+        if not yes and not click.confirm(
+            f"Resize studio from {current_size}GB to {size}GB?"
+        ):
             click.echo("Cancelled")
             return
 
@@ -430,24 +557,44 @@ def resize_studio(size: int, env: Optional[str]):
 
 
 @studio_cli.command("reset")
-@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
-def reset_studio(env: Optional[str]):
+@click.option("--yes", "-y", is_flag=True, help="Skip confirmation")
+@click.option(
+    "--user",
+    default=None,
+    help="User whose studio to reset (defaults to current user, use for testing/admin)",
+)
+@click.option(
+    "--env",
+    default=None,
+    help="Environment (dev, sand, prod) - auto-detected if not specified",
+)
+def reset_studio(yes: bool, user: Optional[str], env: Optional[str]):
     """Reset a stuck studio (admin operation)."""
-    
+
     # Check AWS auth and auto-detect environment if not specified
     check_aws_auth()
-    
+
     if env is None:
         env = detect_aws_environment()
 
     client = StudioManagerClient(environment=env)
 
     try:
-        # Get user's studio
-        studio = client.get_my_studio()
-        if not studio:
-            click.echo("✗ You don't have a studio", err=True)
-            raise click.Abort()
+        # Get studio (for current user or specified user)
+        if user is None:
+            studio = client.get_my_studio()
+            if not studio:
+                click.echo("✗ You don't have a studio", err=True)
+                raise click.Abort()
+        else:
+            # Get studio by user - list all and filter
+            result = client.list_studios()
+            studios = result.get("studios", [])
+            user_studios = [s for s in studios if s.get("user") == user]
+            if not user_studios:
+                click.echo(f"✗ User '{user}' doesn't have a studio", err=True)
+                raise click.Abort()
+            studio = user_studios[0]
 
         studio_id = studio["studio_id"]
         current_status = studio.get("status", "unknown")
@@ -455,11 +602,11 @@ def reset_studio(env: Optional[str]):
         click.echo(f"Studio: {studio_id}")
         click.echo(f"Current Status: {current_status}")
 
-        if current_status in ["available", "in-use"]:
+        if current_status in ["available", "attached"]:
             click.echo("Studio is not stuck (status is normal)")
             return
 
-        if not click.confirm(f"Reset studio status to 'available'?"):
+        if not yes and not click.confirm(f"Reset studio status to 'available'?"):
             click.echo("Cancelled")
             return
 
