@@ -19,7 +19,9 @@ def _find_project_root() -> Path | None:
     """
     current_dir = Path.cwd().resolve()
     while current_dir != current_dir.parent:
-        if (current_dir / ".git").is_dir() or (current_dir / "pyproject.toml").is_file():
+        if (current_dir / ".git").is_dir() or (
+            current_dir / "pyproject.toml"
+        ).is_file():
             return current_dir
         current_dir = current_dir.parent
     # Check the final directory in the hierarchy (e.g., '/')
